==> RIP-0.3.1beta1.tar.gz: RIP-0.3.1beta1/modules/ut/memwrap.h <==
/***************************************
  $Revision: 1.7 $

  Utilities (ut). memwrap.h - header file for memory allocation wrappers. 

  Status: NOT REVUED, TESTED, 

  Design and implementation by: Marek Bukowy

  ******************/ /******************
  Copyright (c) 1999                              RIPE NCC
 
  All Rights Reserved
  
  Permission to use, copy, modify, and distribute this software and its
  documentation for any purpose and without fee is hereby granted,
  provided that the above copyright notice appear in all copies and that
  both that copyright notice and this permission notice appear in
  supporting documentation, and that the name of the author not be
  used in advertising or publicity pertaining to distribution of the
  software without specific, written prior permission.
  
  THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
  AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
  DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ***************************************/

#ifndef _MEMWRAP_H
#define _MEMWRAP_H

#include <erroutines.h>
#include <glib.h>


void wr_log_set(int value);

/*
er_ret_t wr_real_malloc(void **ptr, size_t size) ;
er_ret_t wr_real_calloc(void **ptr, size_t num, size_t size) ;
er_ret_t wr_real_realloc(void **ptr, void *oldptr, size_t size) ;
er_ret_t wr_real_free(void *ptr) ;
*/
char * wr_string(const char *text);

er_ret_t wr_real_malloc(void **ptr, size_t size, char *file, int line) ;
er_ret_t wr_real_calloc(void **ptr, size_t num, size_t size, char *file, int line) ;
er_ret_t wr_real_realloc(void **ptr, void *oldptr, size_t size, char *file, int line) ;
er_ret_t wr_real_free(void *ptr, char *file, int line) ;

#define wr_malloc(a,b)    wr_real_malloc(a,b,   __FILE__ ,__LINE__)
#define wr_calloc(a,b,c)  wr_real_calloc(a,b,c, __FILE__ ,__LINE__)
#define wr_realloc(a,b,c) wr_real_realloc(a,b,c,__FILE__ ,__LINE__)
#define wr_free(a)        wr_real_free(a,       __FILE__ ,__LINE__)

/*void wr_free_list_element(void *cpy, void *trash);*/
void wr_real_clear_list(GList **list, char *file, int line);

#define wr_clear_list(a)  wr_real_clear_list(a,   __FILE__ ,__LINE__)

/* let's see... 
   #define free(a) wr_free(a)   
*/
#endif /* _MEMWRAP_H */

==> RIP-0.4.2beta1.tar.gz: RIP-0.4.2beta1/modules/ut/memwrap.h <==
/***************************************
  $Revision: 1.8 $

  Utilities (ut). memwrap.h - header file for memory allocation wrappers. 

  Status: NOT REVUED, TESTED, 

  Design and implementation by: Marek Bukowy

  ******************/ /******************
  Copyright (c) 1999                              RIPE NCC
 
  All Rights Reserved
  
  Permission to use, copy, modify, and distribute this software and its
  documentation for any purpose and without fee is hereby granted,
  provided that the above copyright notice appear in all copies and that
  both that copyright notice and this permission notice appear in
  supporting documentation, and that the name of the author not be
  used in advertising or publicity pertaining to distribution of the
  software without specific, written prior permission.
  
  THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
  AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
  DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ***************************************/

#ifndef _MEMWRAP_H
#define _MEMWRAP_H

#include <erroutines.h>
#include <glib.h>


void wr_log_set(int value);

/*
er_ret_t wr_real_malloc(void **ptr, size_t size) ;
er_ret_t wr_real_calloc(void **ptr, size_t num, size_t size) ;
er_ret_t wr_real_realloc(void **ptr, size_t size) ;
er_ret_t wr_real_free(void *ptr) ;
*/
char * wr_string(const char *text);

er_ret_t wr_real_malloc(void **ptr, size_t size, char *file, int line) ;
er_ret_t wr_real_calloc(void **ptr, size_t num, size_t size, char *file, int line) ;
er_ret_t wr_real_realloc(void **ptr, size_t size, char *file, int line) ;
er_ret_t wr_real_free(void *ptr, char *file, int line) ;

#define wr_malloc(a,b)    wr_real_malloc(a,b,   __FILE__ ,__LINE__)
#define wr_calloc(a,b,c)  wr_real_calloc(a,b,c, __FILE__ ,__LINE__)
#define wr_realloc(a,b)   wr_real_realloc(a,b,  __FILE__ ,__LINE__)
#define wr_free(a)        wr_real_free(a,       __FILE__ ,__LINE__)

/*void wr_free_list_element(void *cpy, void *trash);*/
void wr_real_clear_list(GList **list, char *file, int line);

#define wr_clear_list(a)  wr_real_clear_list(a,   __FILE__ ,__LINE__)

/* let's see... 
   #define free(a) wr_free(a)   
*/
#endif /* _MEMWRAP_H */
